==> dpdispatcher-0.2.1.tar.gz: dpdispatcher-0.2.1/tests/test_shell_cuda_multi_devices.py <==
import sys, os, shutil, json
sys.path.insert(0, os.path.abspath(os.path.join(os.path.dirname(__file__), '..')))
__package__ = 'tests'
from .context import Submission, Job, Task, Resources
from .context import Shell
from .context import LocalContext
from .context import get_file_md5
from .context import Machine

import unittest

class TestShellTrival(unittest.TestCase):
    def setUp(self):
        self.maxDiff = None

    def test_shell_trival(self):
        with open('jsons/compute.if_cuda_multi_devices.json', 'r') as f:
            compute_dict = json.load(f)
        machine = Machine.load_from_dict(compute_dict['machine'])
        resources = Resources.load_from_dict(compute_dict['resources'])

        task_list = []
        for ii in range(16):
            task = Task(command=f"echo dpdispatcher_unittest_{ii}", task_work_path='./', forward_files=[], backward_files=[], outlog='out.txt')
            task_list.append(task)

        submission = Submission(work_base='test_dir/',
            machine=machine,
            resources=resources,
            forward_common_files=['test.txt'],
            backward_common_files=['out.txt'],
            task_list=task_list
        )
        submission.run_submission(clean=False)

        for ii in ['out.txt', 'test.txt']:
            f1 = os.path.join('test_if_cuda_multi_devices/', 'test_dir/', ii)
            f2 = os.path.join('tmp_if_cuda_multi_devices/', submission.submission_hash, ii)
            self.assertEqual(get_file_md5(f1), get_file_md5(f2))

    @classmethod
    def tearDownClass(self):
        # pass
        shutil.rmtree('tmp_if_cuda_multi_devices/')

==> dpdispatcher-0.2.7.tar.gz: dpdispatcher-0.2.7/tests/test_shell_cuda_multi_devices.py <==
import sys, os, shutil, json
sys.path.insert(0, os.path.abspath(os.path.join(os.path.dirname(__file__), '..')))
__package__ = 'tests'
from .context import Submission, Job, Task, Resources
from .context import Shell
from .context import LocalContext
from .context import get_file_md5
from .context import Machine

import unittest

class TestShellCudaMultiDevices(unittest.TestCase):
    def setUp(self):
        self.maxDiff = None

    def test_shell_cuda_multi_devices(self):
        with open('jsons/compute.if_cuda_multi_devices.json', 'r') as f:
            compute_dict = json.load(f)
        machine = Machine.load_from_dict(compute_dict['machine'])
        resources = Resources.load_from_dict(compute_dict['resources'])

        task_list = []
        for ii in range(16):
            task = Task(command=f"echo dpdispatcher_unittest_{ii}", task_work_path='./', forward_files=[], backward_files=[], outlog='out.txt')
            task_list.append(task)

        submission = Submission(work_base='test_dir/',
            machine=machine,
            resources=resources,
            forward_common_files=['test.txt'],
            backward_common_files=['out.txt'],
            task_list=task_list
        )
        submission.run_submission(clean=False)

        for ii in ['test.txt']:
            f1 = os.path.join('test_if_cuda_multi_devices/', 'test_dir/', ii)
            f2 = os.path.join('tmp_if_cuda_multi_devices/', submission.submission_hash, ii)
            self.assertEqual(get_file_md5(f1), get_file_md5(f2))

        self.assertTrue(os.path.isfile('test_if_cuda_multi_devices/test_dir/out.txt'))

    @classmethod
    def tearDownClass(cls):
        # pass
        shutil.rmtree('tmp_if_cuda_multi_devices/')
